@@ -3,7 +3,7 @@ from __future__ import division
 from __future__ import absolute_import
 from __future__ import unicode_literals
 
-VERSION="2.0.1"
+VERSION="2.0.4"
 PACKAGE="blueman"
 WEBSITE="https://github.com/blueman-project/blueman"
 PREFIX="/usr"
@@ -13,7 +13,7 @@ PIXMAP_PATH = "/usr/share/pixmaps/blueman"
 UI_PATH = "/usr/share/blueman/ui"
 OBEX_BROWSE_AVAILABLE = True
 DHCP_CONFIG_FILE = "/etc/dhcp3/dhcpd.conf"
-POLKIT = "yes" == "yes"
+POLKIT = "no" == "yes"
 
 import os
 import gettext
